{% extends 'garpix_page/base.html' %}

{% block content %}
    <h1>Ура, работает!</h1>
    <p>Вы можете начать создавать ваши страницы.</p>
    <p>Документация по garpix_page - <a href="https://github.com/garpixcms/garpix_page" target="_blank">https://github.com/garpixcms/garpix_page</a></p>
    <p>Документация по garpixcms (на русском языке) - <a href="https://garpixcms.github.io/garpixcms/" target="_blank">https://garpixcms.github.io/garpixcms/</a></p>
{% endblock %}